Module arguments

Module arguments 

Structs

LoaderContext
Context contributed by the active mod loader for argument building. Constructed in launcher/mod.rs from the stored GameData fields.

Functions

classpath_separator
get_classpath
Build the classpath argument pair and return the main class name.
get_game_arguments
Build vanilla + loader game arguments (everything after the main class).
get_jvm_arguments
Build JVM arguments (everything before the main class, excluding -cp).