Module assets

Module assets 

Functions

copy_assets
Copy legacy assets from the object store into a flat resources/ tree.
get_assets
Build the full list of asset items that the launcher must have on disk.