Module bundle

Module bundle 

Functions

check_bundle
Write every CFile to disk and return a Vec<DownloadItem> for every Asset / NativeAsset that is either missing from disk or whose SHA-1 does not match the expected value.
check_files
Verify the SHA-1 of every Asset / NativeAsset that is present on disk.
get_total_size
Sum of size fields for all Asset and NativeAsset items.