Module lwjgl_native

Module lwjgl_native 

Functions

process_json
Patch version’s library list for Linux ARM compatibility.
uses_lwjgl2
Returns true if the game uses LWJGL 2 (org.lwjgl.lwjgl:lwjgl:2.x).
write_xrandr_stub
Write a minimal xrandr stub script into dir and make it executable.
xrandr_in_path
Returns true if the xrandr binary is found in the current PATH.