Structs
Enums
Functions
- mojang_
arch - CPU architecture in the format used by Mojang native classifiers.
- mojang_
os - OS name in Mojang’s format:
"windows","osx","linux". macOS is"macos"in Rust but"osx"in all Mojang JSON. - skip_
library - Returns
trueif the library should be skipped on the current platform.