Structs
- Loader
Context - Context contributed by the active mod loader for argument building.
Constructed in
launcher/mod.rsfrom the storedGameDatafields.
Functions
- classpath_
separator - get_
classpath - Build the classpath argument pair and return the main class name.
- get_
game_ arguments - Build vanilla + loader game arguments (everything after the main class).
- get_
jvm_ arguments - Build JVM arguments (everything before the main class, excluding
-cp).