pub async fn copy_assets(
options: &LaunchOptions,
version_json: &MinecraftVersionJson,
) -> Result<(), LaunchError>Expand description
Copy legacy assets from the object store into a flat resources/ tree.
Only meaningful for old Minecraft versions (assets "legacy" /
"pre-1.6"). The caller is responsible for deciding when to invoke this
based on crate::utils::version_check::is_old.
If the local index file does not yet exist (assets not downloaded), this is a no-op.