Module platform

Module platform 

Structs

LibraryRule
OsRule

Enums

RuleAction

Functions

mojang_arch
CPU architecture in the format used by Mojang native classifiers.
mojang_os
OS name in Mojang’s format: "windows", "osx", "linux". macOS is "macos" in Rust but "osx" in all Mojang JSON.
skip_library
Returns true if the library should be skipped on the current platform.